@@ -132,15 +132,15 @@ impl Default for ConcurrencyProfile {
 
 impl ConcurrencyProfile {
 	pub fn transit_buffer_size(&self) -> usize {
-		self.domain_concurrency * 100
+		self.domain_concurrency * 10
 	}
 
 	pub fn job_tx_buffer_size(&self) -> usize {
-		self.domain_concurrency * 10
+		self.domain_concurrency
 	}
 
 	pub fn job_update_buffer_size(&self) -> usize {
-		self.domain_concurrency * 10
+		self.domain_concurrency
 	}
 }
 
@@ -244,7 +244,7 @@ impl Default for CrawlingSettings {
 			job_hard_timeout:          CDuration::from_secs(60),
 			job_soft_timeout:          CDuration::from_secs(30),
 			load_timeout:              CDuration::from_secs(10),
-			user_agent:                Some(String::from("crusty-core/0.38.0")),
+			user_agent:                Some(String::from("crusty-core/0.41.0")),
 			compression:               true,
 			custom_headers:            HashMap::new(),
 			max_response_size:         CBytes(1024 * 1024 * 2),
